@@ -1,4 +1,4 @@
-#ident "$Header: /cvs/jra1mw/org.glite.lb.state-machine/src/process_event.c,v 1.34 2011/12/14 10:44:18 zsustr Exp $"
+#ident "$Header: /cvs/jra1mw/org.glite.lb.state-machine/src/process_event.c,v 1.34.2.2 2012/07/13 12:32:43 valtri Exp $"
 /*
 Copyright (c) Members of the EGEE Collaboration. 2004-2010.
 See http://www.eu-egee.org/partners for details on the copyright holders.
@@ -609,8 +609,13 @@ static int processEvent_glite(intJobStat *js, edg_wll_Event *e, int ev_seq, int
 			/* consistence check -- should not receive two contradicting ReallyRunning's within single
 			   deep resub cycle */
 			if (fine_res == RET_BADBRANCH) {
-				syslog(LOG_ERR,"ReallyRunning on bad branch %s",
-						e->any.source == EDG_WLL_SOURCE_LOG_MONITOR ? e->reallyRunning.wn_seq : e->any.seqcode);
+				char *jobid_s;
+
+				jobid_s = glite_jobid_unparse(e->any.jobId);
+				syslog(LOG_ERR,"ReallyRunning on bad branch %s (%s)",
+						e->any.source == EDG_WLL_SOURCE_LOG_MONITOR ? e->reallyRunning.wn_seq : e->any.seqcode,
+						jobid_s);
+				free(jobid_s);
 				break;
 			}
 			/* select the branch unless TOOOLD, i.e. before deep resubmission */
